targeting

package
v1.0.0-beta.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: ISC Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ResolvedHost

type ResolvedHost struct {
	Name         string
	Vars         map[string]any
	TargetVars   map[string]any
	StatePath    string
	Target       target.Target
	InventoryRef inventory.Host
}

ResolvedHost is a fully prepared execution target, including merged inventory vars, safe template metadata, derived state path, and a concrete target implementation.

func ResolveHosts

func ResolveHosts(
	ctx context.Context,
	inv *inventory.Inventory,
	selectors []string,
	registry target.ModuleRegistry,
	resolver *secrets.Resolver,
	baseStatePath string,
) ([]ResolvedHost, error)

func ResolveLocalHost

func ResolveLocalHost(registry target.ModuleRegistry, statePath string) ResolvedHost

Jump to