Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ResolvedHost ¶
type ResolvedHost struct {
Name string
Vars map[string]any
TargetVars map[string]any
StatePath string
Target target.Target
InventoryRef inventory.Host
}
ResolvedHost is a fully prepared execution target, including merged inventory vars, safe template metadata, derived state path, and a concrete target implementation.
func ResolveHosts ¶
func ResolveLocalHost ¶
func ResolveLocalHost(registry target.ModuleRegistry, statePath string) ResolvedHost
Click to show internal directories.
Click to hide internal directories.